@@ -1,11 +1,13 @@
 updateFrame <- function (frame , newstrata ) 
 {
+	colnames(frame) <- toupper(colnames(frame))
+	colnames(newstrata) <- toupper(colnames(newstrata))
     nvarX <- length(grep("X", names(newstrata)))
     if (nvarX == 1) 
-        frame$stratum <- newstrata$X1
+        frame$STRATUM <- newstrata$X1
     if (nvarX > 1) {
         stmt <- NULL
-        stmt <- "frame$stratum <- paste("
+        stmt <- "frame$STRATUM <- paste("
         for (i in 1:(nvarX - 1)) {
             if (i > 0) 
                 stmt <- paste(stmt, "frame$X", i, ",", sep = "")
@@ -13,10 +15,11 @@ updateFrame <- function (frame , newstrata )
         stmt <- paste(stmt, "frame$X", nvarX, ",sep='*')", sep = "")
         eval(parse(text = stmt))
     }
-    newstrata$stratum <- as.character(newstrata$stratum)
-    labels <- as.data.frame(cbind(newstrata$stratum,newstrata$DOM1,newstrata$label))
-    colnames(labels) <- c("stratum", "domainvalue", "label")
-    framenew <- merge(frame, labels, by = c("domainvalue", "stratum"))
+    newstrata$STRATUM <- as.character(newstrata$STRATUM)
+    labels <- as.data.frame(cbind(newstrata$STRATUM,newstrata$DOM1,newstrata$LABEL))
+    colnames(labels) <- c("STRATUM", "DOMAINVALUE", "LABEL")
+    framenew <- merge(frame, labels, by = c("DOMAINVALUE", "STRATUM"))
+	colnames(framenew) <- toupper(colnames(framenew))
     write.table(framenew, "framenew.txt", row.names = FALSE, sep = "\t", quote = FALSE)
     framenew <- read.delim("framenew.txt")
     return(framenew)
